pub struct InboundShipmentHeader {
    pub shipment_name: String,
    pub ship_from_address: Box<Address>,
    pub destination_fulfillment_center_id: String,
    pub are_cases_required: Option<bool>,
    pub shipment_status: ShipmentStatus,
    pub label_prep_preference: LabelPrepPreference,
    pub intended_box_contents_source: Option<IntendedBoxContentsSource>,
}
InboundShipmentHeader : Inbound shipment information used to create and update inbound shipments.

Fields

shipment_name: String

The name for the shipment. Use a naming convention that helps distinguish between shipments over time, such as the date the shipment was created.

ship_from_address: Box<Address>destination_fulfillment_center_id: String

The identifier for the fulfillment center to which the shipment will be shipped. Get this value from the InboundShipmentPlan object in the response returned by the createInboundShipmentPlan operation.

are_cases_required: Option<bool>

Indicates whether or not an inbound shipment contains case-packed boxes. Note: A shipment must contain either all case-packed boxes or all individually packed boxes. Possible values: true - All boxes in the shipment must be case packed. false - All boxes in the shipment must be individually packed. Note: If AreCasesRequired = true for an inbound shipment, then the value of QuantityInCase must be greater than zero for every item in the shipment. Otherwise the service returns an error.

shipment_status: ShipmentStatuslabel_prep_preference: LabelPrepPreferenceintended_box_contents_source: Option<IntendedBoxContentsSource>

Implementations

Inbound shipment information used to create and update inbound shipments.